package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$"`0,````````````"``\````!``$7S````#0``+3(```"$``T`"``
M"``H`!P`&P````8````T``$`-``!`#0```$````!``````0````$`````P``
M`5@``0%8``$!6`````T````-````!`````$````!```````!`````0````"B
M7```HEP````%```0``````$``+````&P```!L`````.````#L`````<``!``
M`````@``L"@``;`H``&P*````/````#P````!@````0````$```!-``!`30`
M`0$T````)````"0````$````!`````0``*(\``&B/``!HCP````@````(```
M``0````$9'3E40``````````````````````````````!@```!`````$````
M%`````-'3E4`RK=Q$7^]F$41I`:M^;QHTQ`H90DO;&EB+VQD+G-O+C$`````
M````$0```#\````(````"`00'`""!$`E!```*(0`AJ`"((&"*`0H2T,2@#A(
M1`"*`````````#\```!"````10```$8```!/````4````%,`````````5@``
M`%<```!8````6@```%L```!>```````````?W\5N+4?>SGR:?VNVF\4N?-1D
MU`[D_R$<6''9`<9'XF^+`;+`XTNLA]?Z0BP_Y<)\DN.Z'=/;\F!LH?J;PT^9
MUD,):V;,KV9`G+G$L:#6_^S514+3<`>('(OR.>W;8C/,)8P5"Y<Z#&NCW:>;
MG*E_"@*GX&/A-8!0GAIK5Q"*"DG[X*,````````````````````````#FP``
M````````$@```````/H``````````!(```````*P```````````2````````
MK```````````$@```````7,``````````!(```````')```````````2````
M```"50``````````$@```````1```````````!(````````!```````````B
M```````!B@``````````$@```````N\``````````!(```````&P````````
M```2```````!_@``````````$@```````B4``````````!(```````%!````
M```````2```````!\```````````$@```````3$``````````!(```````$C
M```````````2```````!Z```````````$@```````MT``````````!(`````
M```0```````````@```````!D0``````````$@```````C8``````````!(`
M``````*,```````````2````````+```````````(````````@\`````````
M`!(```````!&```````````2```````"/P``````````$@```````'D`````
M`````!8```````%C```````````2```````!P@``````````$@```````(P`
M`````````!(```````+%```````````2````````Z0``````````$@``````
M`)T``````````!(```````&X```````````2```````"S```````````$@``
M`````:L``````````!(```````#-```````````2```````""0``````````
M$@```````AX``````````!(```````*:```````````2```````!50``````
M````$@```````G4``````````!(```````$$```````````2```````"DP``
M````````$@```````J$``````````!(```````'A```````````2````````
MN```````````$@```````@0``````````!(```````%^```````````2````
M```"1P``````````$@```````/\``````````!(```````'2```````````2
M```````!V0``````````$@```````K<``````````!(```````%*````````
M```2```````"J```````````$@```````&H``````````!(```````)C````
M```````2```````"O@``````````$@```````?<``````````!(```````.D
M``$U;````,@2```+```$`@`!+&````;D$@``"P```G```16,```"0!(```L`
M``,;``$@O````!02```+```#.0`!,T0```(H$@``"P``!"@``2#0```"4!(`
M``L```/H``&S@``````0```8```#+``!(R`````T$@``"P```T\``2DH````
M1!(```L```.P``%>Z`````01```-```#U0`!6?P```&8$@``"P```^```1^X
M````1!(```L```/]``&SL``````0```8```!G``!L!`````3$0``$P``!!8`
M`2NH````N!(```L```0_``$I;````$02```+```#OP`!L1@`````$```%0``
M`W,``2-4```!!!(```L```+E``&S@`````01```8```#S``!L1@`````$0``
M%0``!`\``;.``````!```!<```0U``&Q+`````01```5```"A0`!LY`````$
M$0``&````\4``1?,````2!(```L```/T``%98````)P2```+```#P0`!L1@`
M````(```%0```N<``;.`````!"$``!@```.)``$K?````"P2```+```#70`!
M'_P```#`$@``"P```%0``;-D`````!$`__$```-_``%;E````;@2```+````
MW``!LX0````!$0``&```!$<``218```$T!(```L`7U]G;6]N7W-T87)T7U\`
M7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L
M;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!?1TQ/0D%,7T]&1E-%5%]404),15\`
M4&5R;%]S>7-?:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K
M7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N
M;V-O;G1E>'0`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W
M6%-?9FQA9W,`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N
M;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!0
M97)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?
M<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y
M7W=R87``97AI=`!L<V5E:S8T`')E861D:7(V-`!S=')D=7``8VQO<V5D:7(`
M;W!E;C8T`'-T<G)C:'(`=6YL:6YK`&UE;6UO=F4`<W1R=&]K`'-T<FQE;@!R
M;61I<@!R96%D`&UK9&ER`%]?=F9P<FEN=&9?8VAK`&=E='!I9`!?7VQS=&%T
M-C1?=&EM938T`')E861L:6YK`')E86QL;V,`7U]S<')I;G1F7V-H:P!?7V9P
M<FEN=&9?8VAK`%]?;&EB8U]S=&%R=%]M86EN`%]?<W1A=#8T7W1I;64V-`!S
M=&1E<G(`;65M8VAR`'-T<F-H<@!M96UC;7``;65M<V5T`&]P96YD:7(`9V5T
M=6ED`&%C8V5S<P!M96UC<'D`<W1R8VUP`%]?97)R;F]?;&]C871I;VX`<W1R
M;F-M<`!?7V5N=FER;VX`7U]R96=I<W1E<E]A=&9O<FL`;&EB<&5R;"YS;RXU
M+C0P`&QI8F,N<V\N-@!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!8
M4U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N
M=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M
M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%])3U]S=&1I;E]U<V5D`%]?
M9&%T85]S=&%R=``D9VQO8F%L)`!S:&%?=7!D871E`'AS7VEN:70`7U]B<W-?
M<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S
M971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P
M87)?:6YI=%]E;G8`1TQ)0D-?,BXS-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C,N
M-`!'3$E"0U\R+C(```````(``0`"``$``0`"``,``0`!``(`!``"``(`!0`!
M``(``0`!``(``@`!``$``@`"``$``P`!``(``0`!``(``0`"``$``0`"``(`
M`@`!``(``@`"``$`!0`!``(``@`"``$``@`!``,``@`"``(``@`!``(``0`%
M``(``@`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`"``$`
M`0`!``(``0`!``$``@`!``$``0`!``$``0````$`!````Q$````0``````:6
MD;0````%```$5````!`):1ER````!```!%\````0"6D9=`````,```1K````
M$`UI:1(````"```$=P```````;-X```=F0```````;`0``!,@````````;.`
M``!1@````````;.$``!>@````````;.0``!5@````````;%0```!@0``````
M`;%8```"@0```````;%@```#@0```````;%H```$@0```````;%P```%@0``
M`````;%X```&@0```````;&````'@0```````;&(```(@0```````;&0```)
M@0```````;&8```*@0```````;&@``!#@0```````;&H```+@0```````;&P
M```,@0```````;&X```-@0```````;'````.@0```````;'(```/@0``````
M`;'0```0@0```````;'8```1@0```````;'@```2@0```````;'H```3@0``
M`````;'P```4@0```````;'X```5@0```````;(````6@0```````;((```7
M@0```````;(0```8@0```````;(8```9@0```````;(@```:@0```````;(H
M```;@0```````;(P```<@0```````;(X```>@0```````;)````?@0``````
M`;)(```@@0```````;)0```A@0```````;)8```B@0```````;)@```C@0``
M`````;)H```D@0```````;)P```E@0```````;)X```F@0```````;*````G
M@0```````;*(```H@0```````;*0```I@0```````;*8```J@0```````;*@
M```K@0```````;*H```L@0```````;*P```M@0```````;*X```N@0``````
M`;+````O@0```````;+(```P@0```````;+0```Q@0```````;+8```R@0``
M`````;+@```S@0```````;+H```T@0```````;+P```U@0```````;+X```V
M@0```````;,````W@0```````;,(```X@0```````;,0```Y@0```````;,8
M```Z@0```````;,@```[@0```````;,H```\@0```````;,P```]@0``````
M`;,X```^@0```````;-```!!@0````!KPC_9;\0`@&O3/\%+PC]9"`0"4^A`
MP`!/Q#^!*V```#0V`>`.P!"5ZJ#```[($),K8```-#8#8`[`$)7JH,``#L@0
MDRM@```T-@,@#L`0E>J@P``.R!"3*V```#0V`4`.P!"5ZJ#```[($),K8```
M-#8$``[`$)7JH,``#L@0DRM@```T-@&@#L`0E>J@P``.R!"3*V```#0V`5`.
MP!"5ZJ#```[($),K8```-#8"@`[`$)7JH,``#L@0DRM@```T-@(P#L`0E>J@
MP``.R!"3*V```#0V`Y`.P!"5ZJ#```[($),K8```-#8"L`[`$)7JH,``#L@0
MDRM@```T-@/@#L`0E>J@P``.R!"3*V```#0V`P`.P!"5ZJ#```[($),K8```
M-#8`D`[`$)7JH,``#L@0DRM@```T-@.`#L`0E>J@P``.R!"3*V```#0V`Q`.
MP!"5ZJ#```[($),K8```-#8#,`[`$)7JH,``#L@0DRM@```T-@/P#L`0E>J@
MP``.R!"3*V```#0V!#`.P!"5ZJ#```[($),K8```-#8"$`[`$)7JH,``#L@0
MDRM@```T-@-`#L`0E>J@P``.R!"3*V```#0V`U`.P!"5ZJ#```[($),K8```
M-#8"X`[`$)7JH,``#L@0DRM@```T-@+`#L`0E>J@P``.R!"3*V```#0V`7`.
MP!"5ZJ#```[($),K8```-#8`H`[`$)7JH,``#L@0DRM@```T-@*@#L`0E>J@
MP``.R!"3*V```#0V`6`.P!"5ZJ#```[($),K8```-#8!@`[`$)7JH,``#L@0
MDRM@```T-@'0#L`0E>J@P``.R!"3*V```#0V`E`.P!"5ZJ#```[($),K8```
M-#8$$`[`$)7JH,``#L@0DRM@```T-@$@#L`0E>J@P``.R!"3*V```#0V`?`.
MP!"5ZJ#```[($),K8```-#8"\`[`$)7JH,``#L@0DRM@```T-@*0#L`0E>J@
MP``.R!"3*V```#0V`'`.P!"5ZJ#```[($),K8```-#8!,`[`$)7JH,``#L@0
MDRM@```T-@.@#L`0E>J@P``.R!"3*V```#0V!"`.P!"5ZJ#```[($),K8```
M-#8"(`[`$)7JH,``#L@0DRM@```T-@)P#L`0E>J@P``.R!"3*V```#0V`;`.
MP!"5ZJ#```[($),K8```-#8`@`[`$)7JH,``#L@0DRM@```T-@/0#L`0E>J@
MP``.R!"3*V```#0V!$`.P!"5ZJ#```[($),K8```-#8#P`[`$)7JH,``#L@0
MDRM@```T-@.P#L`0E>J@P``.R!"3*V```#0V`0`.P!"5ZJ#```[($),K8```
M-#8#<`[`$)7JH,``#L@0DRM@```T-@&0#L`0E>J@P``.R!"3*V```#0V`+`.
MP!"5ZJ#```[($),K8```-#8`T`[`$)7JH,``#L@0DRM@```T-@+0#L`0E>J@
MP``.R!"3*V```#0V`,`.P!"5ZJ#```[($)-KPC_9-]X!`#?</JEKQC\9:\4_
M(0-@"*5KQ#\I-\0^L6O#/S$WPSZY#)D2@`@$`EEKV#ZI"!P"6`QZ$H#H7QN]
M"`,"6B.,,``B;#``-YP/@#9S#X@/@!"8#F`0FNA"#K@(&`)9*V```$`F!-B0
MP#``Z``"4BM@``!(/`3`#X4`DPQ@$)I"?`;\UY\<'F)\!OPW10`&UY\8`C=:
M``B#7(+P(RT@`.A?%WW76@A"#(`0GP@<`E</X!"3*V````^3$H`T(040#&`0
ME@P\$H`CBP``-YP$>"M@```._!*(-"$`*`P@$)P._!*0(XL``#><!(".PD)H
M#OP2F#03``(V_``8#_,@E0N3"I0V<P`"BM,_W0Z5$H`VU@`&"O8*EB.,,``.
MP!*`-YP/D"M@```/@!"9-",%&`@%`E@,8!":Z%\<W6O`/YF3@#``Z``!$NA?
M%QT,8!":(THP``@<`D0WV3\1Z$`$J#=:#W"'@"#H*V```.A?&S4,8!":Z%\:
MK0@``D!+QC\92\4_(0@$`EQ+PC[92\0_*4O#/S'H0,``-]X_`>A?&*4(``)`
M*V```#0A!1@,/!*`AX`@\`@<`EKH7QE="``"0"M@``!(/`3`#X4`G.@?'3UC
MA@Q<Z%\7Y0Q@$)KH'Q[/-"4%"`R@$)J'0"`8-]D_$>A`&\P(``)`Z!\>WR-*
M,`#H0`-@-UH.J`R\$H"'@#ZU"!P"6N@?'Z\C2P``-SD`(.A?&KTW6@+@Z!\=
MS306``CH7Q:--!H``@@``D`/P!*9:\(_V3?>`(`/WA*9:],_P6O7/Y$C;2``
M-WL","-*,`!+6@W`-!<``#06``!KUC^9:]X_B>A?&(4(``)`!`````@``D!K
MPC_9;\0`@&O#/XDK8```2#P$J`^`$(.$8"!`"!,"1&O3/\'H0@J0"`,"6H>`
M(!@(!`)3"`,"5NOB"D`('P)"2\(_64O#/XGH0,``3\0_@2M@``!KPC_9-#H`
M,#?>`(`K8```-#P`,(.:(#`CBC``-YP-V`^`$):&P"`82\(_6>OB";`('P)"
M2\(_6>A`P``WWC^!*V```&O"/]DT.@`P-]X`@"M@```T.0`P"UD$&=,\'Z+3
M.1@?"YD*&=,Y'\&'("`P(XHP`#><#>`/@!"6AL`@&$O"/UGKX@D`"!\"0DO"
M/UGH0,``-]X_@6O"/]DK8```0#P$^&_#`("/@"`@"`$"0^A?'HT(``)`-!P`
M`F!\!/A+PC]9Z$#``$_#/X%KPC_92\(_V>@?'LT(``)`"``"0&O"/]DK8```
M-"$$T&_)`0!KR#\)"!D"2&O&/QEKQS\1:\4_(6O$/REKPS\Q#"`0B84@(9@(
M&@)&#T`0'-.<'_B'@"`@-`4``).<('HT'``"DX`@`.@``,H-(!"#A&`@:`@)
M`D0T!P!Z"`4"6`@&`EGH7Q65"`,"6H^`(!H,HP`<TYP?^`N'.(#H``"Z#(@P
MHXQ@/ZT(!0)8"`,"7$O"/ME+R#\)2\<_$4O&/QE+Q3\A2\0_*4O#/S'H0,``
M3\D_`0@:`D4,HC`\TYP?^).3('HT$P`"AX`^_PC%!`6.8#_/#*(P/.@?'MT(
MQ00%"20$!#2E``+0A!^B"*,*`^@?'RT-!!*`Z!\?'0@)`D-KPC_9-]X!@#?9
M/I%KPS]QZ%\.G0@:`D/+G*"`2],^L2*G(``B@@``"K,"$X)T(!`BA0``BG0@
M6$O"/ED(`P):Z%\/!309``1+PS]QDYPP`#0<``)+PCY9Z$#``#?>/H$T'```
M2\(^64O#/W'H0,``-]X^@6O"/]DWW@&`:\8_<6O%/WEKQ#^!:\,_B<BZ(!(,
MH!`<DX`@`.@``#)+PCY92\8_<4O%/WE+Q#^!2\,_B>A`P``WWCZ!Z%\,_0@`
M`D#(?#^U2\(^6>A?$$T(`P):RYPA<D.3`"8V<S^ECF`@&#>$`"8,@A`3AF`_
MM0@``D!#DP`F-G,_I9)@,`#H``%RZ%\2U0@%`EH(!`):Z%\2O0@<`D8+A@H:
MZ%\3'3=:``1KQ#^1-!@__P@<`D1KQ3^9-!D``@@<`EHBZC``Z%\113;W#>@(
M!`):Z%\+C3?9/I&'GR`P"`0"6DO</K$BAR``(F(```J<`AP+DSB`Z```TNA?
M"Q4(``)`Z%\2-0@$`EKH7P[="`,"6LN<OI=#DP`FZ%\3'0@#`EKH7PL5"`4"
M6DO&/W%+Q3]Y2\(^64O$/X%+PS^)Z$#``#?>/H$,@A`3-G,_I8Y@/FT(``)`
M#(00'(>`/>4(``)`Z!\>1^A?'24(``)`Z!\?'VO"/]DWW@$`:\8_,6O%/SEK
MPS])"!H"0VO)/QEKR#\A:\<_*6O$/T$/(!`<DX`P>K<E$`((&0)%Z%\0E0@%
M`EHWV3\1"!P"1NA?&7T(`P):R)PB6"M@``#H7Q!5"`0"6HC<@?!+R#\1*V``
M`-4("$(T)P30#&`0'-.<'_B'@",X-!0`>H.4(RH(`P):#T(P,])S'_B28#``
MZ```"HIT/]\/0C`S"'H$&@S@$(0TQ@`$"00*!.A?$!4+1@H:AX`@Z`R<$H`,
MX!"3#&`0'#1Z``+3E1_X#1,`DS04`'J"M"!8#GP2`(Z@("`V=0`"Z```2#0<
M`'J#E"`P-G4``@]`$!P.?#(BTYP?^(^`/\TW6@`"-G4``C0<`'H.?!(`-!,`
M``YE`!P*=0H4#IP2`-.<'_B/@#_5-G,``DO"/ME+R3\92\@_(4O'/RE+QC\Q
M2\4_.4O$/T%+PS])Z$#``#?>/P$T$P``#F4`'`ID"A0.G!(`TYP?^(^`/]4V
M<P`"Z!\?=4O"/MDT)P30#.`0B0T@$)R'@"$@-!D`$`@$`E,TA``"#20@G(^`
M/^<(!`)3-G,`!M<S"$(K8```-"$%``P@$)R/@"!X-!P``@P\$H#H7PWE"!D"
M6LI\/KW5!`A""!,"6@@)`EGH7P;]"`@"6`S\$H`('`)3"F0*DVO$/Q'H'QSE
M#F`2B.A?!S4("0):#/P2@(>`/D4('`)3Z!\?K=4$"$+H'QT%-!H``.@?'PT(
M'`)$:\(_V308'_XWWB$`:\4_$0@9`D4WV1\1:\0_&0@:`D0C2C``:\,_(>A?
M!4TW6@WXCX!`.`@<`D,WG#__-]0?$0^4`!..8""`"`,"6(^`(&@('`)#*V``
M`$@\!,`#8`BS#Y,`F@@%`ECH7PR="`0"64O%/Q%+Q#\92\(>V4O#/R'H0,``
M-]X?`0@#`E@T&0!>Z%\)I3?:'Q&'@#]M"`,"5RM@``!(/`3``V`(LP^3`)H(
M!`)9Z%\,?3?8'Q%+Q3\12\0_&4O"'ME+PS\AZ$#``#?>'P$CC#``-YP/:&O"
M/]D/@!"8;\0`@"+L,``C*C``:\,_B2M@``!()`3``V`(HPR#`)HV]P_8Z%\&
M-3<Y#AAKP#^1(XPP`#><#W`/@!"8(NL``",J,``V]P1P-SD.4&O7/YGH7P1-
M#(,`FDO#/XE+PC]9Z$#``$_$/X$CC#``-YP/>`^`$)AKPC_9*V```$@\!,`#
M8`BS#Y,`FC?>`(`B[#``(RHP`#;W#]CH7P5--SD.&$O"/UGH0,``-]X_@2O!
M``!KPC_9-#X!`&O#/QGH7P>M"``"0")J,``V<PZ8:]P_F308(`(T&0`":],_
MD3?:'Q,BZC``Z%\'_3;W#H`C/L__-!@@`#<Y/Q`WVA\3Z%\!W0O9"AG(?$"0
M-!,``.A?"3TT>@`"RGP@0`@3`EH(`P)8(S[/_S<Y/Q#H7P15"]D*&0@<`E,(
M?`H<#X`2``@3`EQ+PS\9*][__S0^#P!+PC_9Z$#``DO#/QD($P)<*][__S0^
M#P!+PC_9Z$#``FO"/]E+PC_9Z!\>90@``D`(``)`:\(_V3?>(@!KQ3]!"!H"
M12-*,`!KQ#])-UH.J&O#/U$(&0)#:\\^\6O./OEKS3\!:\P_"6O+/Q%KRC\9
M:\D_(6O(/REKQS\Q:\8_.>A?$$TWV1X1-!D`7@@<`D3H7P,]"`4"6I.`,`#H
M``"B"`4"62-*,`#H7Q7E-UH.P`@%`EQ+PAW92\\^\4O./OE+S3\!2\P_"4O+
M/Q%+RC\92\D_(4O(/RE+QS\Q2\8_.4O%/T%+Q#])2\,_4>A`P``WWAX!"`,"
M6NA?`_T@RC``--D.X.A?`O4('`):R'P_'2$*,``@ZC``#&`0'#0)'_XWS#^)
M-\L_D34(#O@WRC^9-.<.Z#?./C&'@"&X(:<@`(2`("`(`P)9Z%\%%0@$`EJ'
M@"%0--D.X.A?!94(`P):-!4`7C>3/_\*8PH3B'.@(`@<`D_H``!*-G,__PAS
M.(#H```:#F`0%-*4'_B"E3_/#F`2`.A?!1T(`P):"!P"3^A?!04(!0):"?P*
M'#><``*#B9W5-!D``@V%$H`WVAX1#6@2@`@'`E<T&"``Z%\#E0U#$H`WV3X1
MZ%\=V3?:'A&/@"`P--D.X`W`$)PB9```";P"'(.3(+`T&0`"--D.X.A?`/TT
M&@``R'P]+0@%`ED,8!`<CX`^30@``D"$@"`:#(`0'#></Z63@#``Z```&B!J
M,``T#P`"Z!\>Q31C#J`,@A`<AX`_;339#N#H'Q_%(&HP`.A?'DDWVAX1CX`_
M/339#N`WV1X1(THP`.A?$ETW6@[`Z%\!!3?:'A'H'QQM2\(=V6O"/]DT&0!>
M;\,`@.A?`OT(&@)#-YH``I.`,``(`P):Z%\`I0@``D!+PC]9Z$#``$_#/X%K
MPC_9-]XA`&O%/Q%KQ#\9:\,_(<BZ(4(,H!`<DX`P`.@``2KH7P*-"``"0#03
M(``WF``"@Q.!6`@<`D,WQ!\1"`4"6>A?'A$(!`):-'P__PN$"AR(G*`H-!0`
M7N@``$`T&0!>-YP__X"<("@T&0!>#X`0$])S'_B"=#_/#X`2`#09`%[H7P&E
M"`0"6LN<(%@C2C``")RH@.@``(+H7Q]!"`0"6DO%/Q%+Q#\92\(>V4O#/R'H
M0,``-]X?`2-*,`#H7Q[Y-UH.H$O%/Q%+Q#\92\(>V4O#/R'H0,``-]X?`>@?
M'VT/@!(`-!P``$O"'ME+Q3\12\0_&4O#/R'H0,``-]X?`6O"/]DK8```-]X!
M`&O$/SDT)`30:\,_02!J,``T8P\`:\@_&6O'/R%KQC\I:\4_,3?9/Q'H7PEM
M"`,"6H>`('!+TS\1#(`0G`N3"IP/B!"3AF`_M0^3$H`/D!"3#Y,2B(Y@/^4W
MG``(-]D_$>A?"/T(`P):CX`_E4O3/Q$@:C``*V```#1C#Q@T)`30-]D_$>A?
M"+4(`P):AX`@<$O3/Q$,@!"<"Y,*G`^($).&8#^U#Y,2@`^0$),/DQ*(CF`_
MY3><``@WV3\1Z%\(10@#`EJ/@#^52],_$2!J,``K8```-&,/*#0D!-`WV3\1
MZ%\'_0@#`EJ'@"!P2],_$0R`$)P+DPJ<#X@0DX9@/[4/DQ*`#Y`0DP^3$HB.
M8#_E-YP`"#?9/Q'H7P>-"`,"6H^`/Y5+TS\1(&HP`"M@```T8P]`-"0$T#?9
M/Q'H7P=%"`,"6H>`('!+TS\1#(`0G`N3"IP/B!"3AF`_M0^3$H`/D!"3#Y,2
MB(Y@/^4WG``(-]D_$>A?!M4(`P):CX`_E4O3/Q$@:C``*V```#1E#U`T)`30
M-]D_$>A?!HT(!0):AX`@<$O3/Q$,@!"<"Y,*G`^($).&8#^U#Y,2@`^0$),/
MDQ*(CF`_Y3><``@WV3\1Z%\&'0@%`EJ/@#^52],_$2"*,``K8```-(0/<#0E
M!-`WV3\1Z%\%U0@$`EJ'@"!P2],_$0R@$)P+DPJ<#X@0DX9@/[4/DQ*`#Y`0
MDP^3$HB.8#_E-YP`"#?9/Q'H7P5E"`0"6H^`/Y5+TS\1((HP`"M@```TA@ZH
M-"4$T#?9/Q'H7P4="`8"6H>`('!+TS\1#*`0G`N3"IP/B!"3AF`_M0^3$H`/
MD!"3#Y,2B(Y@/^4WG``(-]D_$>A?!*T(!@):CX`_E4O3/Q$@JC``*V```#2G
M#X@T)@30-]D_$>A?!&4(!P):AX`@<$O3/Q$,P!"<"Y,*G`^($).&8#^U#Y,2
M@`^0$),/DQ*(CF`_Y3><``@WV3\1Z%\#]0@'`EJ/@#^52],_$2#*,``K8```
M-,@/H#0G!-`WV3\1Z%\#K0@(`EJ'@"!P2],_$0S@$)P+DPJ<#X@0DX9@/[4/
MDQ*`#Y`0DP^3$HB.8#_E-YP`"#?9/Q'H7P,]"`@"6H^`/Y5+TS\1(.HP`"M@
M```TYP^X-"@$T#?9/Q'H7P+U"`<"6H>`('!+TS\1#0`0G`N3"IP/B!"3AF`_
MM0^3$H`/D!"3#Y,2B(Y@/^4WG``(-]D_$>A?`H4(!P):CX`_E4O3/Q$@ZC``
M*V```#3G#L`T*`30-]D_$>A?`CT(!P):AX`@@#?9/Q%+TS\1#0`0G`N3"IP/
MB!"3AF`_K0^3$H`/D!"3#Y,2B(Y@/^4WG``(-]D_$>A?`<4(!P):CX`_E4O3
M/Q$WV3\1(THP`.A?`94W6@_0"!PR6>@```KH7P==--H/H#?9/Q$C2C``Z%\!
M53=:#_C+/"`2(TL``.A?!QTW6@`@-]D_$2-+``#H7P$5-UH`.`@<,EGH``!J
MZ%\&W32:#J@T>@]0(RL``$O"/ME+R#\9-SD`@$O'/R%+QC\I2\4_,4O$/SE+
MPS]!Z!\&?3?>/P$WV3\1(TL``.A?`'4W6@!8RSP_?S1Z#U#H7P8]-+H/B.@?
M'UTT>@]0:\(_V2-*,``WW@"`-UH/B.A?`!4WV3^1RYP@,@^`$!PT$P`"TYP?
M^).`(`"3G#!@-!P``@I\`IQ+PC]9Z$#``#?>/X%KPC_9-]X`@&O7/R$WUS\Y
M:]@_*6O9/S$.^A*`"!H"6"M@```T(03P:]<_D0P@$)KH7Q(Q-!D``NA?$L$T
M&@'^"``"0&O"/]DKR```-!P`!#0^`0!KS3\I-!<``#08``!KRS\Y-\T_F0@:
M`DMKQC]A:\4_:6O./R%KS#\Q:\H_06O)/TEKR#]1:\<_66O$/W%KPS]YZ%\4
M.0V\$H"WI@?_"!P%!="]'!\+I0*5"Z8"E@@=`EP('0)3"[8$%@N5!172U1OP
M"[4"E`NT!!T+DP4<"Z8$!@N%!06,H&'X(8@``".8S_\K8```-YP_$30.```U
MC``0"YX*!#0*`!`T*0`0-`<__R$8S_\-KA*`"`4"5P@&`ECH7Q,Y"`L"6H>?
M(:@(#`)8"`0"6>A?#WD("P):DX`W_^@``6*/CH$`-YP_\0N$"@.(@X`8"`H"
M6.@``-J`@X#0"`H"6`@)`EGH7P[!"`,"6H^`/\\T8S__"(,$`P@#`EW0?!P?
M"Z8&'0N%!QQ+SC\A2\T_*4O,/S%+RS\Y2\H_04O)/TE+R#]12\<_64O&/V%+
MQ3]I2\0_<4O#/WDKU___-#X/`$O"/]GH0,`"",@&!@BG!P6,OSY_#:X2@".8
MS_^(W#YG#:X2@#0</_\T'3__Z!\?-4O./R$C2P``Z%\<%3=:`*B/OSY-"``"
M0"-+``#H7QOM-UH`B`@``D!KPC_9-]X`@.A?#7$(``)`Z%\0^0@<`EK+G"`"
M#X`0G$O"/UGH0,``-]X_@6O"/]DWW@$`-]D_$6O%/R$@JP``:\0_*0@:`D1K
MQC\9:\,_,>A?&NDTN@#`R'P@$@Q@$!R3@"``Z```0@@$`EDTN@#`2\(^V4O&
M/QE+Q3\A2\0_*4O#/S'H'P!M-]X_`>A?$6D(!`):"`,"6NA?$5$('`)&"X8*
M&NA?$;$W6@`$:\,_B2)J,``V<P[@:\0_F0@<`D,T&0`":],_D2+J,``T&#__
M-O<.Z.A?#\$('`):Z!\?%0@#`EEKPC_9(XL``#?>`H`WG`#P:\H_(2M_W_]K
MR3\I-"$->"%*,`!KQS\Y-\<^N0@:`DEKQ#]1-\0^<0@$`E5KPS]9-\,^H3?9
M/9%KTC[A-5H.J&O1/NEKT#[Q:\\^^6O./P%KS3\):\P_$6O+/QEKR#\Q:\8_
M06O%/TD,_!*`(XHP`#><#J`,_!*(-!P`(`PH$+,,*!"T#K,2J*^17]T.M!*H
M(XL``#><`0`,?!*`(XL``#><`1`,X!*0#&`2D.A?&$D,?!*(R1P@$@T`$!R3
M@"``Z``)6NA?"A$(``)`Z%\-F0@<`EK+G"2"#X`0CY'@,`#H``1JZ%\.T0@/
M`EK77`@AZ%\/,3=:``(-X!`3"!P"0])S'_B&8"D`"!P"2R&+```WR#^9-8P!
M*#0./_\T#0`"TG,;^`@#`EH-$Q*`"`P"5P@.`E@(#0)9Z%\-$31C``0-XC`S
MTG,?^(Y@/ZW2<QOX(XL``.@``!`WF@`@DT`P`.@``'+H7Q;9-]D]D<A\/]<,
MB#"Z#&`0'(>`/[\,B#"ZZ%\8N0@#`EJ'@#^?#(@PNNA?"R$(`P):"!PB0^@`
M`&(,X!"#A&`@4@Q@$!S3G!_XDX`P`.@``YKH7QA)"`,"6H^`(U`TYP`(#.`0
M@XQ@/[<,8!`<"`,"6NA?#.DWS3^)"`L"6NA?#-$('`)$"X0*!#2$"`@(!`):
MZ%\-(3?,/Y%KRS^!(FL``#9S`5`-LQ*`(6HP`#5K#O@-BQ*`"!P"1S09``(-
M`Q*`"!P"6B+K```T&#__Z%\+&3;W`3@WSC^!-!D#@.A?"'D(!P):CY\@,#?9
M/9'H7P9Y"``"0`^`$)PT$P`BBY,ELC?9/9'H7P6I"`<"6LA\H#@K8```2]P]
ML2*'(``B8@``"IP"'(.3(?@WSSVQ*V```#0A!/`-!Q*`#2`0ER,+```,(!":
M-Q@!V.A?#%$T&0`"-`0```@$`EQ+PCU92](^X4O1/NE+T#[Q2\\^^4O./P%+
MS3\)2\P_$4O+/QE+RC\A2\D_*4O(/S%+QS\Y2\8_04O%/TE+Q#]12\,_6>A`
MP``WWCV!Z%\(*31C``C)_+N5"``"0`Q@$)J30#``Z```2NA?$U$WV3V1RUP@
M$@]`$!R/@#^="``"0#1C``@,8!":CT`_M0@``D`T&@`:Z%\*:2'K```U[P#@
M"!P"0P@<`DOH'QL]-!,`INA?!V$(`P):R'P\3PS@$(/H'QRE"`,"6N@?'(T(
M'`)#Z%\$>4O0/<&*'#WU*V````W@$)PT$P.`TYP;]XN3/=4T(03PZ%\)J0@$
M`EHWV3V1(TL```@<`D3H7Q(1-UH"@`@<,EGH``-RZ%\!!0T@$)H('#)0Z``#
M4NA?",D($`):CX:`<`@<`D\WFC_Y(RL```M0"AKH7P?Q-SD"D).`(`#H```R
MA>@DT`GP"@\T$P!>#?<0'-.<'_@+DSB`Z``$HB$J,``WV3V1Z%\1,34Z#XC+
MG"*J#X`0'-.<'_B'@"*8-!D``).<,&`T'``"DX`@`.@``G(U.@^((RL``#<Y
M`(#H7Q:I(*L``.A?!?$TI01P#<42@"+K```-O!*`-O<"Z#08/_\-BQ*`-!D`
M`@@$`EH-!Q*`(,L``.A?!C$T"0.`-`\`(C?2/WDTQ@,(-!$__^@``(@T$``"
MZ%\!D0@``D`/@!"<"X\H@.@``(+H7P4I-&,``@Y%$H`-PQ*`"`8"5PV\$H`(
M$0)8"!`"60V+$H`(!`):Z%\%>0T'$H`("0)9Z%\"X0@$`EJ'GS]5"``"0.A?
M!JD(!P):-5H.J.A?%3$(!`)9Z%\3_0@$`EKH'QK]"`0"7`V<$H`K8```-#P$
M\`T@$)<C"P``#0<2@#<8`6`/@!":Z%\&Z309``+H'QJ5-`0``.A?$WT("`):
MZ%\#20@(`EKH'QIE"!P"1.@?%WTWR#^9Z!\<G0T@$)`T&0``Z%\%@0@0`EK)
M_#UU-3H/B.A?#Q4(#P):"!P"18R@?44('0)&M-@'[0@%!1<(#P):Z%\#N0T`
M$H`WT#[1-!@`#`@/`EKH7A_]"!`"68^,(:`CF@`(#@`0DS><`H:*?#S--3H/
MB"."```."!!3-YP0BHI\/*TC*P``M-@'G0@%!1<(#P):-`,``.A?`PD-`Q*`
M-!@`4#?9/9'H7A]5"`\"6C03`%"+DR#P(XL``#><!'`-W!*`-]P]D0V\$H`T
M&#__#8L2@"+K```T&0`"8\,]X3;W`L@(!`):Z%\"D0T'$H#H'QTW#2@0B84@
M.T\A*C``Z%\#>0@)`EJ/AILO(2HP`#></_DC*P``"XD*&NA?`J$W.0*@DX`P
M``@)`E#H'QKE(2HP`"-+``#H7PQ=-UH"L`@``D`K8```2#P$P&O"/]DWW@$`
M:\,_*2-*,`!KQ3\9`V`(HVO$/R$/@P"$-]D_$3=:#U!`G`#0Z%\+D6"<`-++
MG"`B#X`0$S04`&+2<Q_X"G0X@.@``NKH7P%U"``"0"M@``!(/`3`#X,`A",K
M```T%P`&-!@``C<Y`TCH7A]="`0"6LN<(&@('`)$2YP`(",+```/@!"9*V``
M`$@E!,`,HP":Z%\">3<8`U!(G``@#X`0F0\P$)S3@-T_Z``"<BM@``!()03`
M#*,`FB,K```T%P`&-!@``NA>'J4W.0-@R)P@0C?9/Q$C2C``Z%\**3=:#L!(
MDP`@RQPAP`Y@$)GH7P'!#*,`FBM@``!()`3`#(,`A308``((!0):(RL``.A>
M'9TW.0-H"`4"6@@<`EDC"P``Z%\!63<8`Y@,@P"<-]D_$6.``-(C2C``Z%\)
M:3=:#J@K8```-"0%"`R<$H"'@"!X"!P"0S09`X#H7AR-"`,"6C>3``*.8H`@
M2\(^V9.3("(T$P`"CF`@\`@<`E=+Q3\92\0_(4O#/RGH0,``-]X_`2M@```T
M(040#"`0FNA?#M4(``)`#)P2@(^`/TT('`)#(TL``.A?``DW6@.H#X(0'(>`
M/2TC*P``Z!\<[RM@```T(040#"`0G`@9`EKH7Q)I#X`0F>@?'A?H7AI]#*,`
MFN@?'6\K8```-#P%$`^`$)PC2P``#X`0F0@#`ECH7A]=-UH#\`@``D!KPC_9
M-]X!`#?9/Q%KPS\A"!H"0R-*,`!KQ#\9Z%\'<3=:#XC+G"!2#X`0'-.<'_B3
M@"!@DYPP`#0<``*/@"`H2\(^V81@(!H,8!`<DX`@`.@``")+PC[92\0_&4O#
M/R'H0,``-]X_`>A?&O$(`P):-!D`7@@<`D3H7AV-"!P"6C>:``*3@#``"`0"
M6NA>&S4(``)`(RL``#08``@W.0%0Z%X<[0@<`EJ/@#]52\(^V0@#`EI+Q#\9
M2\,_(>@?"3$WWC\!"``"0&O"/]D(&@)?-]X'@#=4`'`WTSB1:](^R6O1/M$(
M$P)<-U<`\&O0/MDT'0``:\\^X6O./NEKS3[Q:\P^^6O+/P%KRC\):\D_$6O(
M/QEKQS\A:\8_*6O%/S%KQ#\Y:\,_00Z`$)8.B!"5-YP`(#:4`!`/EA*)#X`2
M@0^=$I&*ES^]#Y42F3?).+%+S3EA2\PY:3?5.1%+RSEQ2\HY>3?4.9$V<00`
M2](Y@4O<.8DT'0``2\8XP4O%.,E+Q#C12\,XV4O"..%+VCCI2]DX\4O8./E+
MSSD!2\XY"0T@$(CH```0#2@0AP@7`D\(%@).#J`0EPZH$)8('`)0"!("00Y@
M$)P.:!"2"OP"G`K2`I()O`*<"9("D@Z=$H`(\@*2"1P"G`I<`ES27`@<#IP2
MB`@+`DT("@),"`8"2`@%`D<(!`)&"`,"10@"`D0(&@)#"!D"0@@8`EH(#P)9
M"`X"6`@=`E(V<P`0-K4`$#:4`!`(`0)+BG$^W0@0`DHW^0`@#^`0BP_H$(Q+
MUSC!2]@XR3?C`$!KV3WI#&`0A0QH$(8("P)""8("66O%/:%KQCVI#2`0D0TH
M$)(BDSM0-!,``#:4`S)KUSZ!:]@^B4O%..%+QCCIT9D(F`@=`E=+R3CQ2\HX
M^4O9.8%+VCF)-^$`,`F"`D)KPSVY2\,XT4O$.-G1@@NB"!T"1VO#/D%KQ#Y)
M2\,YD4O$.9DT'```:\4^,6O&/CE+Q3B12\8XF6O)/B%KRCXI2\D]H4O*/:EK
MV3X!:]H^"0C4!AH(LP<9"TH&&@LI!QE+]0`@2_8`*$OO`#!+\``X#_`0C0_X
M$(X+&@88"OD'%VO#/=%KQ#W9"?4"@PFC`AEKT3Z1:](^F0H6`H1+T3D!2](Y
M"0G$`@0)^0*)"@0"BFO!/>$+"@8*"ND'"0G-`EE+USEA2]@Y:6O1/A%KTCX9
MT=D+NDO1.7%+TCEYT5D8FVO1/E%KTCY9:]<^86O8/FE+USBA2]@XJ=4*"*4+
M%`88"O,'%TO#.1%+Q#D9"R@"1FO#/G%KQ#YY"!D"10L0!@0*[P<#"[4"F6O#
M/J%KQ#ZI"7D"&0JY`ID(&@)8T4H+L0A:`IH(&0)#"5H"&@L6`IE+R3ZA2\H^
MJ0F9`AD*V0*9"!D"1`B*!@0(:0<#2\D^D4O*/ID+&@*("(8&&@AE!QEKV3ZA
M:]H^J4O#/JG08PNRT&48F]3#"*4)5`8$"3,'`P@%`DD(E@8$"'4'`PD$!@0(
MXP<#"!T"5TO'/H%+R#Z)"*8"2@B*!@8(:0<%:\4^D6O&/IE+R3Z9T2,8FPD4
M!@@(\P<':\,]^6O'/H%KR#Z)2\,^@4O$/HD(F`8$"'<'`];I"*5+V#ZI:\,^
M@6O$/HD(`@):T2D+H0@=`D=+R3WY"B("@@DW`DH+`@("2]<^@4O8/HEKW3Z!
M"T("B`D8!@@(]P<'"0H&"@CI!PE+R#Z9U.H(I6O'/J$('0)9"!$"1@I1`I$)
M$0(12\<^04O(/DD)%`88"/,'%PC1`H@('0)'"QH&&`KY!Q<)&`8:"/<'&=%)
M&)MKV3Z1:]H^F4O7/J$("0)9"3<"6DO7/I%+V#Z9"QH&&`KY!Q<(,@*::]<^
MH6O8/JE+V3ZI"5H"&M%*"Z)+USXQ2]@^.=,Y"['3*1B;"Q0&&`KS!Q<($@)$
MU5D(I0I:`I)KTCZ)2]D^@4O:/HD('0)%"P8&!@KE!P4+1@88"R4'%P@)`ED)
M*@):"QH&"@KY!PE+V3ZI:\D^D6O*/ID(`0)(2]<^F0A!`H'55PBE"R$""6O*
M/J%+V3XA2]H^*=+W"[+2X1B;:]T^@0M4!A@+,P<7"!T"0PD)`IH('0)9"P0&
M&`KC!Q<+6`88"S<'%TO#/J$(`0))"","2@L*!@H*Z0<)2]<^$4O8/AD+%`88
M"O,'%VO7/J%KV#ZI2]@^F0HB`IH+&@(:2]<^H4O8/JD+"`8("N<'!]%)&)L(
M6@*7:]<^B4O9/H%+VCZ)"T@&&@LG!QD(`@)&:]D^H6O:/JG42@BE2]<^H4O8
M/JD)(@):"`D"60L:!A@*^0<7:]<^H6O8/JD($0)$2]<^J==7"*4*40*1:]H^
MD4O9/G%+VCYYTO<+H@E1`@D('0)%TO$8FPM4!A@+,P<7"(D"F@@=`ED+!@88
M"N4'%TO&/I$+6`88"S<'%]%*"Z$($0))"B8"2@L*!AH*Z0<9"#("EVO7/G%+
MUSDA2]@Y*6O7/H%KV#Z)"!("2`@=`D-+V#ZI2](^<0L2`A((`0)&2]<^@4O8
M/HD+%`88"O,'%VO2/G$(00*!:]<^H6O8/JE+V#YQ"!T"1VO9/I%KVCZ9"1@"
MF@@=`EE+USZA2]@^J4O)/ID+!`8$"N,'`]$I"[$+1`88"R,'%]$J&)O5*0BE
M"`H"60E)`EH+&@8*"OD'"4O9/IEKR3ZA:\H^J0LA`@E+USZI"!T"6=+W"[+2
MX1B;",D"FM57"*5KRCZ12]<Y,4O8.3D+%`88"O,'%PL(!A@*YP<7"U@&&`LW
M!Q=+V3Z1"`$"20@Y`DH+"@8:"ND'&6O9/I%KVCZ92\D^F0HB`I=KUSYQ"`("
M1$O"/G%+USE!2]@Y26O7/H%KV#Z)"!T"6=$J&)M+V#ZI"P("`FO"/G'1*0NA
M2]<^@4O8/HD+%`88"O,'%VO7/J%KV#ZI"!$"2$O8/G$(F`*:U$D(I6O=/H%+
MUSZA2]@^J0L&!@8*Y0<%"E$"D0M&!A@+)0<7"`H"60E"`EH+&@8*"OD'"6O)
M/J%KRCZI2]<^J=<W"*72]PNB:]D^D4O*/ID('0)#"5$""0@=`EG2\1B;2]<Y
M44O8.5D)"0*:"Q0&&`KS!Q<+!`88"N,'%PM8!A@+-P<72]H^D0@1`DD*.@)*
M"PH&"@KI!PE+USYA2]@^:0L4!A@*\P<7:]<^D6O8/IE+V#ZI"#("F@L:`AI+
MUSZ12]@^F0L(!@@*YP<'T4D8FPI:`I=KUSZ)2]D^@4O:/HD+2`8:"R<'&0@2
M`D9KV3ZA:]H^J=9*"*5+USZA2]@^J0DR`EH("0)9"QH&&`KY!Q=KUSZA:]@^
MJ0@!`D1+USZIUU<(I0A!`H%KVCZ12]D^44O:/EG2]PNR"4$""6O=/H'2X1B;
M"!T"10M4!A@+,P<7"(D"F@@=`ED+!@88"N4'%TO&/I$+6`88"S<'%]%*"[$(
M`0))""8"2@L*!@H*Z0<)2]<^`4O8/@D+%`88"O,'%VO7/I%KV#Z92]@^J0HB
M`IH+&@(:2]<^D4O8/ID+!`8$"N,'`]%)&)L(6@*7:]<^B4O9/H%+VCZ)"T0&
M&@LC!QD(`@)(:]D^H6O:/JG42@BE2]<^H4O8/JD)(@):"`D"60L:!A@*^0<7
M:]<^H6O8/JD($0)&2]<^J==7"*4*40*1:]H^D4O9/=%+VCW9TO<+H@E1`@D(
M'0)'TO$8FPM4!A@+,P<7",D"F@@=`ED+"`88"N<'%TO'/I$+6`88"S<'%]%*
M"Z$($0))"B<"2@L*!AH*Z0<9"#("F&O8/G%+USFA2]@YJ6O7/H%KV#Z)"!("
M1`@=`D-+V#ZI2](^<0L2`A((`0)(2]<^@4O8/HD+%`88"O,'%VO2/G$('0)'
M:]<^H6O8/JE+V#YQ:]D^D6O:/ID(F`*:"!T"64O7/J%+V#ZI2\D^F0L&!@8*
MY0<%T2D+L0M&!A@+)0<7T2H8F]4I"*4("@)9"4D"6@L:!@H*^0<)2]D^F6O)
M/J%KRCZI"$$"EPLW`@E+P3ZI"0D"F@@=`EE+USFQ2]@YN0L4!A@*\P<7"P0&
M&`KC!Q<+6`88"S<'%P@=`DD*(@*9T"$(B@L*!@H*Z0<)"#D"%]`A"[((`@)&
M"!T"60C7`II+USG!2]@YR0L4!A@*\P<7"E$"DPL(!A@*YP<7"U@&&@LW!QG1
M2@B)2]<YT4O8.=D("0)$"T0&"`LC!P<)4P*::\<^H6O(/JDBCYW:-!,``#:4
M!T)+R#ZI"Q0&&`KS!Q<('0)%"!T"60L&!@8*Y0<%2]<YX4O8.>D+1@8:"R4'
M&0L4!@0*\P<#T4H+H@@=`E<($0)8"!T"24O1/JG1"`B*"TH&"@LI!PD(F`8:
M"'<'&=$("Z=KV3Z1:]H^F4O7/I%+V#Z9"%("B`@=`ED**`*:"!T"0]%*"(8+
M&@88"OD'%TO9.?%+VCGY"`8"1`L$!A@*XP<7:]<^H6O8/JE+R#ZI"U0&!`LS
M!P,(X@*)"!T"60E)`IH('0)7"!("6`B8!A@(=P<7"QH&&`KY!Q=+V3H!2]HZ
M"=%*"Z71"`NF"!T"0]$("(@("`)$"P0&"@KC!PD('0)7"U0&&@LS!QD(IP*1
M"`("6`M8!AH+-P<92]<^J0KQ`I$($0)$-!<``#08```+1`8:"R,'&4O#.A%+
MQ#H9")0&!`AS!P,(!P)8")@&&`AW!Q<T`P``-`0``-%*"Z@(Q0*'"!T"40E'
M`H?12@B2"`<"1`M2!A(+,0<1"P0&&`KC!Q<('`)9TE((F@L:!@H*^0<)"08"
MB4O9.B%+VCHI"!P"5PM4!AH+,P<9"`4"6`@<`D,+6`8:"S<'&0I)`HD("0)$
M"T0&&@LC!QG24@N]2\,Z,4O$.CD+J`*)"!P"4=%*")()20*)"U(&$@LQ!Q$(
ME`8:"','&=%*"Z(('`)#"`D"1`@&`E@+6`88"S<'%P@<`ED+!`88"N,'%])2
M")H+&@8*"OD'"4O9.D%+VCI)"!P"5PM4!AH+,P<9"%T"B0@(`E@*20*)"U@&
M&@LW!QD("0)$"T0&&@LC!QG24@NE2\,Z44O$.ED(H@*)"!P"4=%*")()20*)
M"U(&$@LQ!Q$(E`8:"','&=%*"Z8('`)#"`D"1`@=`E@+6`88"S<'%P@<`ED+
M!`88"N,'%])2")H+&@8*"OD'"4O9.F%+VCII"!P"5PM4!AH+,P<9",4"B0@"
M`E@*20*)"U@&&@LW!QD("0)$"T0&&@LC!QG24@NG2\,Z<4O$.GD(Y@*)"!P"
M4=%*")()20*)"U(&$@LQ!Q$(E`8:"','&=%*"[T('`)#"`D"1`@%`E@+6`88
M"S<'%P@<`ED+!`88"N,'%])2")H+&@8*"OD'"4O9.H%+VCJ)"!P"5PM4!AH+
M,P<9"Z<"B0@&`E@*20*)"U@&&@LW!QD("0)$"T0&&@LC!QG24@NB2\,ZD4O$
M.ID(70*)"!P"4=%*")()20*)"U(&$@LQ!Q$(E`8:"','&=%*"Z4('`)#"`D"
M1`@'`E@+6`88"S<'%P@<`ED+!`88"N,'%])2")H+&@8*"OD'"4O9.J%+VCJI
M"!P"5PM4!AH+,P<9"*("B0@=`E@*20*)"U@&&@LW!QD("0)$"T0&&@LC!QG2
M4@NF2\,ZL4O$.KD('`)1T4H(D@C%`HD+4@82"S$'$0E)`HD(E`8:"','&=%*
M"Z<('`)#"`D"1`@"`E@+6`88"S<'%P@<`ED+!`88"N,'%])2")H+&@8*"OD'
M"4O9.L%+VCK)"!P"5PCF`HD*20*)"`D"1`M4!AH+,P<9"`4"6`M8!AH+-P<9
M"T0&&@LC!QE+PSK12\0ZV=)2"[T('`)1"Z<"B-%*")()2`*("U(&$@LQ!Q$(
ME`8:"','&0@(`D312@NB"!P"0PA=`HH(!@)8"DH"B@M8!A@+-P<7"!P"60L$
M!A@*XP<7TE((F@@*`D0+&@8&"OD'!4O9.N%+VCKI"!P"5PM4!AH+,P<9"`<"
M6`M8!AH+-P<9"T0&&@LC!QE+PSKQ2\0Z^0B4!A@(<P<7:]<^H6O8/JE+PSZA
M2\0^J=)2"ZD('`)1T,8(D@@<`E<+4@82"S$'$0@=`EC211B;U/((I0B8!A@(
M=P<7"*<"6@@<`D,)(@*="`4"60C=`IT('0)$"P0&&`KC!Q<+&@8$"OD'`P@<
M`EEKPSZA:\0^J0@"`EI+PSZITE(+JDO7.P%+V#L)T,8+J-!D&)MKR3Z9"`@"
M1@D)`H=KW#Z1"Q0&&`KS!Q<)2`)("QH&&`KY!Q<*1P*4"48"&@AH`AD('`)3
M"Q0&%`KS!Q/08PN]U$,(I0M9`D@(@@)2:\@^B0@$`E%+PSL12\0[&0J2!A(*
M<0<1:\,^H6O$/JDBG;'C-!,``$O9/J%+VCZI-I0)N`M4!AH+,P<9"YP"`VO9
M/J%KVCZI2]D^D4O:/IEKPSZ!TE$8F]0R"*5+PSZA2\0^J0B:!@0(>0<#2]D^
M@4O:/HD+1`8$"R,'`VO#/J%KQ#ZI"B$"2$O#/J%+Q#ZI"ZH"&@@1`D<("@)8
M"(@&!`AG!P,+J@)*:\,^H6O$/JE+V3ZI"DH""M,Y"['24@NBTR$8FP@<`D4+
M2@)(2\D[(4O*.RG660BE"YP"!PE4!AH),P<9"T8&&@LE!QD)&@8("/D'!P@R
M`DH(`0))"0H&&@CI!QE+QSLQ2\@[.6O'/H%KR#Z)2\<^@4O(/HD)%`8("/,'
M!VO'/H%KR#Z)"!P"5TO%/H%+QCZ):]D^D6O:/ID(V`88"+<'%PA=`@%+R3Z9
M2\4^J=$I"[+1*AB;U2D(I0@=`D0+G`('"%T"70E)`D8(O0(="`H"10@]`D@)
M&`8("/<'!PD&!@H(Y0<):\D^H6O*/JE+Q3ZI2\<^F4O).T%+RCM)"B("!@@"
M`EH*(@)"".("`M"E"[W0H1B;"!P"0PC"`D@+G`('U$4(I0E4!@8),P<%"`$"
M20C$!@8(HP<%"08&"`CE!P<((@)*"0H&`@CI!P%KP3Z1:\(^F4O)/ID*40((
M:\@^<4O#.U%+Q#M9"!P"60B4!@@(<P<':\<^@6O(/HE+PSZ!2\0^B0B:!@0(
M>0<#T2D+HFO#/H%KQ#Z)T2H8FTO$/JD*40)9U2D(I0B9`AD)20))"!$"6`N<
M`@=+T3YQ"`H"0PHY`DA+V3Z!2]H^B0@)`D0)&@8("/D'!PD$!@H(XP<)"!("
M1FO)/J%KRCZI2\<^F4O#/JE+R3MA2\H[:0NR`@0+L@)2"/("$@B2`DC08PNQ
M"!T"6M!A&)L+G`('UD,(I0A=`ET)5`8$"3,'`P@<`E<(,@)*")@&&`AW!Q<(
M`0))"1@&&`CW!Q=+R#ZI"PH&&`KI!Q<)'0(!"B("5],8"[W56`BE"[$"2&O*
M/I$+%P($TQ(8FVO$/H%+USP!2]@\"6O(/G$+%`8$"O,'`PA:`@I+QSMQ2\@[
M>0@<`D4)%`8("/,'!VO*/J$)!@8(".4'!VO#/<%KQ#W)2\4[\4O&._D(`@)$
M"YP""4O"/J$(00)*"4@&"@DG!PD(U`8("+,'!TO"/I%KQSW1:\@]V0@1`D8*
M0@)("!("1PE(!@@))P<'",0""M$("Z)KRCY1"%T"1TO*/G'1$1B;:\<^80D*
M`A+4*`BE2\D[@4O*.XEKR3ZA:\H^J4O'/J%+R#ZI"10&"`CS!P=KTCZ1"!P"
M64O2/H%KQSZA:\@^J0N<`@D('`)#2\@^40D2`DH('`)%2\<^H4O(/JD)&@8(
M"/D'!PE(!AH))P<9:]D^H6O:/JE+QSZA2\@^J0HA`DH($0))"0H&"@CI!PD(
M'0)(T5(8FPD&`A%KTCWY:]$^H4O1/F$)40(2T4H+O6O2/E'4*@BE2]$[D4O2
M.YD('`)':]$^86O2/FE+R3YA2\H^:0E4!@H),P<)"YP"$6O!/G$+H@)!"!P"
M66O)/F%KRCYI2\H^H0@<`E=KP3WQ2\$^D0E!`E)+R3YA2\H^:0E$!@H)(P<)
M"DH&!`HI!P-+T3OA2]([Z6O#/J%KQ#ZI"E0&"@HS!PE+Q#YQ:\D^`6O*/@E+
MR3WY"20"2DO#/J%+Q#ZI"(H&"@AI!PG12@NA2](]\0@"`D1KP3YQT5$8FPA(
M`@$)4@(":]$^86O"/?'6*@BE2\(^<0A=`DEKT3WY"YP"$4O"/E$((@)2:\D]
ML4O).Z%+RCNI"50&"@DS!PD)1@8&"24'!0I&!@H*)0<):\D^46O*/EE+T3WY
M"!T"1DO)/F$),0)*2]$^44O2/ED*2@8*"BD'"0C$`A+12@NQ:](^46O1/L'1
M71B;2]$]L0E1`A)KW3YAUZH(I0@<`D5KTCVQ2](^P0@<`D$('`)#:]T]^4O=
M/G$*70)=2]$[L4O2.[EKT3ZQ:](^N4O)/K%+RCZY"50&"@DS!PEKR3ZQ:\H^
MN0N<`A%+RCY1:]T]F4O=/?$)70)22\D^L4O*/KD)2`8*"2<'"0I*!@@**0<'
M:\<^L6O(/KE+R3YA2\<[T4O(.]D)%`82"/,'$0I&!@@*)0<'2]$^L4O2/KEK
MQSY1:\@^64O(/?D)*`)*"DH&$@HI!Q%KT3ZQ:](^N4O)/KG1*0NJT3(8FTO(
M/G$("@)":\H^<=5)"*5KTCYA2](^P0A2`E(('`)':\H]^0D&`@9KTCV12\D^
M`4O*/@D)2`8*"2<'"4O1/<%+TCW)"D(&$@HA!Q%KR3X!:\H^"0N<`@EKT3W!
M:](]R4O=/KE+TCVQ2]$]F0C2`DH+L0(12\4[P4O&.\D(U`8&"+,'!0C$!@8(
MHP<%2\0]^0E&!@H))0<):]$]\4O1/F$*)`)2"5(&!`DQ!P-+RC[!:\,^86O$
M/FD("@)$2\4^:0B(`@A+P3WQT*88F]"E"[UKQCZA2\<^:=2E"*4(Q0)1:]$^
MJ0D!`D9+R#V1"Z("40NB`A((2@(*"YP"!0CH`@)+QSY12\@^66O%/I$)0@)!
M"YP"!6O!/IEKQ3Y!2\$^D4O"/ID(R`8&"*<'!0@<`D-+QSZA2\@^J0C(!@8(
MIP<%"-$"!4O'/@%+R#X)"$@&"@@G!PD*10)!:\$^20@&`D(+G`(!:\$^(=!'
M&)O40@BE:\<^@0CB`E)KTCZ)2\$^@4O"/HD)0@8("2$'!TO)/=%+RCW9"40&
M"@DC!PE+PSY!2\0^20B*!@0(:0<#T,8+IFO#/J%KQ#ZI"-T"10C=`A'1`QB;
M:\,^,0D%`@+4B`BE"!T"6@AD`D%KP3XYT0@+O4O'/J%+R#ZI"B("1$O1/C%+
MTCXY:\0^*0D2!@H(\0<)2\$^(4O"/BG121B;U*H(I0DE`DA+PSW!2\0]R6O)
M/A$(1`82"",'$6O(/AD+I@(!2\<^$4O(/AD(!@)8"D@&"`HG!P=KQSZA:\@^
MJ4O)/JD+I@)&T4H+HDO'/!%+R#P9"48""@D4!@8(\P<%:\4^D6O&/IE+Q3Z1
M2\8^F=$I"['1,AB;""H"2`N<`@<(V@8:"+D'&=4I"*4)&@8&"/D'!0@=`D0(
M$@)'"DD"2`A=`ET(R`8*"*<'"4O%/JE+QSPA2\@\*0B]`@9KQSZA:\@^J0A$
M`@%KQCZ!2\4^H4O&/JD(U`8&"+,'!0N<`@=KQ3ZA:\8^J4O&/H$()@)("`("
M6FO)/I%KRCZ92\4^H4O&/JD(V`88"+<'%PHB`D)+R3Z9T2D+O=$J&)O5*0BE
M"1@&!@CW!P4("@)'"4D"2`C(!@H(IP<)2\4^F6O)/H%KRCZ)"YP"!PHZ`@I+
MTCZ)"*(""4O%/#%+QCPY"4D"2`C4!@8(LP<%TE((B@@<`D,(Q`8$"*,'`PD$
M!@0(XP<#"!P"20B*!@@(:0<':\<^H6O(/JE+RCZI2\,^B0@1`E@('`)9#_P2
M@`N<`@<+L0)1#_P2D`AQ`A%+PSQ!2\0\20B4!@0(<P<#2],^J=)2"Z(('`)7
M"[@"$@B:!@0(>0<#2]D\44O:/%D*40)("00&!`CC!P,(70*'"F<"AR*6"4TT
M$P``-I0#K`M4!AH+,P<9"U@&&@LW!QD('`)1T4H(D@B2!A((<0<1"!P"0])2
M"(@(!P)$"!P"1PB:!@0(>0<#"(@&&@AG!QG12@NI:]D^H6O:/JE+R#ZI"2("
MEP@<`ED*5P*:"!P"14O7/&%+V#QI"!T"1@L4!A@*\P<7"P8&&`KE!Q<+6`88
M"S<'%TO9/'%+VCQY"U0&&@LS!QG24@N]T0@+IP@<`E'1"`B2"ZD"B`L2!A(*
M\0<1"!P"5P@"`E@+6`88"S<'%TO9/JD+*`*("`@"1`@<`D,('`)9"P0&&`KC
M!Q?24@B:"/T"B`I(`H@("`)$"QH&`@KY!P%+V3R!2]H\B6O!/J%KPCZI"U0&
M&@LS!QE+QCZI"!P"5P@)`EC0Q@B*"U@&&@LW!QD('`))"T0&&@LC!QE+PSR1
M2\0\F0M*!@H+*0<)TE(+I0B4!AH(<P<92](^J0BG`HD*20*)"`D"1-#&"Z((
M'`)#"$4"B0@=`E@)20*)"U@&&`LW!Q<+!`88"N,'%TO9/*%+VCRI"`D"1-%*
M"Z8+5`8:"S,'&0@<`E'12@B2"!P"20L2!A(*\0<1"!P"5P@'`EC24@B*"U@&
M&@LW!QD+1`8:"R,'&4O#/+%+Q#RY"TH&"@LI!PD(E`8:"','&0C"`HD*20*)
M"`D"1-)2"[T('`)#"Z8"B0@%`E@)20*)"U@&&`LW!Q<('`)9"P0&&`KC!Q?1
M2@B:"`D"1`L:!A(*^0<12]D\P4O:/,G12@NG"U0&&@LS!QD('`)7"`("6`@<
M`DD+6`8:"S<'&=)2"(H+1`8:"R,'&4O#/-%+Q#S9"TH&"@LI!PD(E`8:"','
M&0C]`HD*20*)"`D"1-)2"Z4('`)#"*<"B0@&`E@)20*)"U@&&`LW!Q<('`)9
M"P0&&`KC!Q?12@B:"`D"1`L:!A(*^0<12]D\X4O:/.G12@NB"U0&&@LS!QD(
M'`)7"!T"6`@<`DD+6`8:"S<'&=)2"(H+1`8:"R,'&4O#//%+Q#SY"TH&"@LI
M!PD(E`8:"','&0A%`HD*20*)"`D"1-)2"Z8('`)#",("B0@'`E@)20*)"U@&
M&`LW!Q<('`)9"P0&&`KC!Q?12@B:"`D"1`L:!A(*^0<12]D]`4O:/0G12@N]
M"U0&&@LS!QD('`)7"`4"6`@<`DD+6`8:"S<'&=)2"(H+1`8:"R,'&4O#/1%+
MQ#T9"TH&"@LI!PD(`@)8")0&&@AS!QD+I@*)"!P"0PM8!A@+-P<7"DD"B0@)
M`D0+!`88"N,'%])2"Z<('`)9T4H(F@L:!A(*^0<12]<](4O8/2D+%`8""O,'
M`6O!/J%KPCZI-!<``#08``!KUSZ1:]@^F=%*"Z4(_0*$:\8^F0E$`H%+V3Z1
M2]H^F6O7/H%KV#Z)-`D``#0*``!+USZA2]@^J0L:!A@*^0<7:\$^B=)2"(I+
MV3Z!2]H^B0L:!A@*^0<7"PH&"@KI!PE+V3TQ2]H].0@<`E<(IP*)"DD"B0@)
M`D0+5`8:"S,'&0@=`E@+6`8:"S<'&0M$!AH+(P<92\,]04O$/4G24@NB"!P"
M40A%`HG12@B2"4D"B0M2!A(+,0<1")0&&@AS!QD("0)$T4H+I@@<`D,(!P)8
M",("APM8!A@+-P<7"D<"APL$!A@*XP<7"!P"6=)2")H(!P)$"QH&"@KY!PE+
MV3U12]H]60@<`E<+5`8:"S,'&0@%`E@+6`8:"S<'&0M$!AH+(P<92\,]84O$
M/6G24@NH"!P"4=%*")(+4@82"S$'$0B4!AH(<P<9"!P"0]%)&Z()!@*%"`("
M6`E%`H4+6`88"S<'%P@%`D0('`)9"P0&&`KC!Q?24@B:U&H+W@L:!@(*^0<!
M:\$^H6O"/JE+W3ZI"2,"6M.B&)L+2`*%"!P"5PI%`I@("0)92\D]<4O*/7D(
M'`)#"50&"@DS!PD(!@)$"40&!`DC!P,(F`8$"'<'`]4]"*4(`@)%"$D"1@B&
M!@((90<!2\,]@4O$/8D(E`8$"','`])1&Z((C`8,"&L'"]3R"]X('`)3"B<"
M1@C:`H,+HP*4T%P(D@@<`DG4@@BE"`("6`@(`DH+#@88"NT'%PF*!@@):0<'
M#_@2F$O*/;D)%`8("/,'!]."&)L*1`)4"%("4TO"/>E+Q#WA"10&%`CS!Q,/
M]!*(T[\;HDO'/:%+R#VI#%P2@->]"]X('P)3"_T"5`J6!A0*=0<3#%02B`R<
M$H`($0)%"-`&!@BO!P4,AA*("T@&&@LG!QD-7!*`#5H2B$O".%E+TC[)2]$^
MT4O0/ME+SS[A2\X^Z4O-/O%+S#[Y2\L_`4O*/PE+R3\12\@_&4O'/R%+QC\I
M2\4_,4O$/SE+PS]!Z$#``#?>.(%KPC_9-]X`@.A=%R4T&@$`:X``\"+)3.@T
M%0``-M8&`@^5$H`/EA*((LW=^305```VU@<2#Y42D`^6$I@BUK,7-!4``#;6
M"?QKE0`@:Y8`*"+2(@8T%0``-M8([&N5`#!KE@`X(M<(>S05```VU@/@:Y4`
M0&N6`$@T%0``-!8``&N5`%!KE@!8:Y4`8&N6`&A+PC]9Z$#``#?>/X%KPC_9
M-U8`4#=?`&!ORP$`"!@"2]%U'!]KQ3\QT74(7->K"&-KQ#\Y"!D"16O*/PEK
MR3\1:\@_&6O'/R%KQC\I:\,_00[`$)<.R!"8"[@&%`N7!Q,/X!"'#^@0B([@
M(;@(&@)$@Q2!J@[`$H#6=0ACT7T870[4$H@+LP)=TKP870NH!AT+AP<<#_P2
M@`_]$H@TB@#P#4`0FH]`(6`TA@!P-!P`?HE\0*C1?!LF"`4"0]3\",8U:S^!
M-XD__PCE"@<T"`"`"`,"60@&`EH("`)8Z%T/K31C`(#H7A:U"`0"6HAG/\4(
M`P)9"`L"4]>)",;68!P:-*4`@`N+!`L(LPH%"`L"6`@%`EGH70\]"`8"6@U+
M$H!+PC[92\H_"4O)/Q%+R#\92\<_(4O&/RE+Q3\Q2\0_.4O#/T'H0,``3\L_
M`;4(``((!P<'Z!\>/0[`$H"71P"`"`4"60CK>(`("P)'"T8*&NA=#H4(!P)8
M#4`0G`N'"APT$P"`BY,_+0U<$H`(ZP0+".4*!>A>%54(!`):Z!\>'30<`'YK
MPC_9-!,_`6_*`0`T"@!P:\D_"3<I`'!KQ#\Q"!H"1&O#/SD(&0)#:\@_$6O'
M/QEKQC\A:\4_*4LE`%C0N!N:"PD*'$LF`%!+)P!@-Q@``@L)"AI+*`!HBPI"
MB`^3$@"7&`"`Z%T-S309``#H7A1="`,"6@@*`E@T&0``Z%T-G0@)`EK1!PCU
MT0<)]#0<``#1!PKGUY4/&->4#AC7APT8UX@,&&A\`.#0I@CUT*8)]#0<``#0
MI@KFUY4/&->4#AC7A@T8UX4,&&A\`.CH7A.="`,"6@QH$!P,G!(`"`,"6@QH
M$%P,G!("#&P0%0R5$@0,:!"5#)42!@QX$!4,E1((#'@050R5$@H,?!`5#)42
M#`QX$)4,E1(.0'4`*`R5$A!$=0`H#)42$D!U`"P,E1(42'0`*`R4$A9`=``X
M#)02&$1T`#@,E!(:0'0`/`R4$AQ(<P`X#),2'D!S`$A@DP`@1',`2&"3`")`
M<P!,8),`)$A\`$CH70^]8)P`)DO)/PE+R#\12\(^V4O'/QE+QC\A2\4_*4O$
M/S%+PS\YZ$#``$_*/P&7&`!PZ%T+1309``#H'QVET0<(]2M@``!(/`3(:\(_
MV6_$`(!KTS_!Z%T,M0^`$)=+PC]9Z$#``$_$/X'2P+O?ZL#``@[=$)7JH,``
M#L00DVO"/]D(&@)<;\0`@&O#/XF'7R#8:],_P304'_X+5(B`Z```NL?:P+`(
M&@)#U&`<'@1C,922@#``Z```B@Q@$)32E1O^CJ`@>$O"/UD&@S&4DH`P`.@`
M`%H,:!"9-]P`'M>`#!T/@!'<#&`0G"M@```WG``@2#\$N(/\("@BAP^!#&`0
MG$O"/UE+PS^)Z$#``$_$/X$/\1"6#MD0G`J<`A<CH`T!@OT@,#;5/_E*W`!`
M"IP"%(*=(!`VU0!`Z!\?A30</__7O`H?TY0;EM;<"0@+M`)4-!T(``NV`A;3
MG!GP"M0"5-><"7L+E`)<TI09\(:`(!#6W`A"UY\>,=;<"$(/^1"<*V````K5
M"A5(-@2P-K4`$`[<$H@/Z!":#M42@-;?'#_K_QV%"!\"0@Q@$)SH'QZE2\(_
M66O"/]EOQ`"`:],_P0@3`D1+PC]9"`0"4^A`P`!/Q#^!``&S0@`!LRH``@`!
M```````````E<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB
M;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`````+W!R;V,O
M)6DO)7,`97AE`"X```!005)?5$5-4`````!005)?4%)/1TY!344`````.@``
M`"5S)7,E<P``+P```%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/4%0`````
M4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.
M````4$%27T1%0E5'````4$%27T-!0TA%````4$%27T=,3T)!3%]$14)51P``
M``!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]435!$25(``%!!4E]'3$]"04Q?
M5$5-4`!005)?1TQ/0D%,7T-,14%.`````#$```!L<V5E:R!F86EL960`````
M<F5A9"!F86EL960`3$1?3$E"4D%265]0051(`%-94U1%30``+W1M<`````!5
M4T52`````%5315).04U%`````"4P,G@`````)7,E<R5S)7,`````<&%R+0``
M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P
M97)A=&EO;BD*``!0051(`````'!A<FP`````+G!A<@````!S:&]R="!R96%D
M```E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U
M+25U)7,`````5$5-4$1)4@!435``&````'!E<FP`````,````%!!4CHZ4&%C
M:V5R.CI615)324].`````#$N,#8S````56YA8FQE('1O(&-R96%T92!C86-H
M92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M90``+2T`
M`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?
M7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D
M8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2
M+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*
M)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S
M7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*
M;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE
M(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@
M)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@
M;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@
M)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H
M*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?
M34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D
M8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R
M;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I
M<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H
M<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN
M9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL
M("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M
M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ
M5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I5
M3DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64[
M"G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@
M73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M
M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*
M9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P
M,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL
M(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI
M.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F
M:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?
M96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@
M/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G
M.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y
M9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE
M*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?
M<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S
M96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@
M>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO
M=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C
M(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA
M<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?
M1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD
M(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE
M(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P
M;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A
M9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B
M7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C
M:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H
M92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S
M("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,
M15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I
M.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T
M(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@
M+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?
M1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B
M"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA
M;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B
M+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B
M=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@
M/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE
M?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M
M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L
M;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@
M7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF
M+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M
M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U
M<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE
M?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII
M9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W
M*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#
M86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD
M9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T
M=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I
M;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@
M/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD
M(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA
M;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H
M)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII
M9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA
M;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^
M("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI
M<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*
M;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]
M("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II
M<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S
M86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@
M*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@
M)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P
M87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N
M7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=
M(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%
M55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E
M:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=6
M6S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF
M("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@
M*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G
M02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G
M3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L
M92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G
M86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS
M:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE
M('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D
M,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD[
M"FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG
M4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`
M24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T
M.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@
M*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O
M<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE
M<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG
M('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII
M9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY
M;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>
M7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I]
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D
M<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=
M.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I
M<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#
M.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/
M.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ
M1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI
M(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H
M+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H
M9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D
M;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A
M;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!
M4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2![
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D
M;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O
M=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R
M96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,
M;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI
M8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!8
M6%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D[
M"FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS
M92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<
M421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q
M*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD
M?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D
M,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0[
M"GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D
M=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C
M:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65]
M(#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N
M9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S
M92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT
M+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@
M86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D
M;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE
M;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R
M:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7
M<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R
M:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO
M<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]
M"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB
M*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C
M='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T
M>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@
M/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A
M8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X]
M(")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M
M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@
M)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L
M;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B
M.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S
M<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER
M92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U
M:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F
M:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F
M:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH
M*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@
M7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H
M:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@
M>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO
M=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@
M*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T
M;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X
M="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E
M>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M
M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H
M+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E
M9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I
M;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L
M<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D
M97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H
M)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@
M<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE
M(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"([
M"GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2![
M"F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP
M87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O
M9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`
M05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D
M97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN
M*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H
M)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E
M<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q
M=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R
M:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@
M0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I
M<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER
M92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R
M97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E
M<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@
M871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U
M:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE
M=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![
M(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E
M<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@
M>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY
M("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2
M(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI
M('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD
M("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P
M=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E
M9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN
M,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S
M97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U53
M15).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP
M9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U
M<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER
M.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD
M)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM
M>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L
M96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E
M96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG
M=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H
M+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C
M86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@
M*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[
M4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C
M86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-
M4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`
M7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H
M+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B
M.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H
M<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L
M("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE
M+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D
M9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O
M*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*
M:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[
M4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA
M;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II
M9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S
M>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R
M;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA
M;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T
M=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?
M<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!
M4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S
M+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D
M9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@
M+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?
M<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!
M345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@
M>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@
M)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I
M"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H
M*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<
M+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E
M;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E
M='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF
M;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!
M344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-
M4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D
M14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"
M04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[
M4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*
M:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP
M<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I
M9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF
M:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP
M('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP
M86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2
M.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A
M<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@
M<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE
M.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/
M4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@
M)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH```&R.@`!L:(``;(Z``&QB@`!LDH`
M`;%*`$-!0TA%`````6`0``%@%``!89@``5]8``%AH`````!P97)L>'-I+F,`
M`````!$D```1/`@!``@````(```5C```%\@(!``(````$```&!0``!A@"`(`
M"`````@``!AD```8I`@```@````(```8J```&/P(```(````"```&0```!DP
M"`$`"`````@``!DT```91`@```@````````92```&E`(!P`(````$```&E0`
M`!K$"`$`"````!@``!K(```<.`@$``@````8```</```'F@(!P`(````$```
M'FP``!\\"`,`"````A```!]````?M`@"``@````(```?N```'_@(```(````
M"```'_P``""X"`$`"```!!```""\```@S`@```@````````@T```(QP(#0`(
M```"(```(R```"-0"`$`"`````@``"-4```D5`@#``@```(0```D6```*20(
M!@`(````$```*2@``"EH"```"`````@``"EL```IK`@```@````(```IL```
M*W@(#``(```@$```*WP``"ND"```"`````@``"NH```L7`@$``@````0```L
M8```,T`($``(````*```,T0``#5H"`,`"````!```#5L```V,`@"``@````0
M```V-```65P($``(````>```66```%GX"```"`````@``%G\``!;D`@)``@`
M```0``!;E```74@("``(````$```74P``%UP"`$`"`````@``%UT``!=A$@`
M``````````!=B```7KP(`@`(````"```7L```%[<"`$`"`````@`````````
M!````!`````!1TY5```````````#`````@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````;$R``&Q0@`!L3H`````````````````````````````
M`````````````0```P$````!```#$0````P``1$D````#0`!7L`````9``&P
M`````!L````(````&@`!L`@````<````!&___O4``0%H````!0`!"&`````&
M``$"8`````H```2!````"P```!`````5``````````,``;$8`````@```O0`
M```4````!P```!<``0XP````!P`!#?0````(````/`````D````,;____@`!
M#:1O____`````6____```0SB````````````````````````````````````
M```````````````````````````````````````*4$%2+G!M"@```````6)$
M``$8%``!L1@``1D```&Q&``!&30``;$8``$?0``!L1@`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````.@!"5
MZJ#```Z($)7JGQ_=UH`<'@#`_^[>K;[O``&P*````````;`D``&SJ``!LV0`
M``````&Q'$=#0SH@*$1E8FEA;B`Q-"XR+C`M,3<I(#$T+C(N,```````!@``
M```````!,#$N,#$````````&``````````$P,2XP,0`````N<VAS=')T86(`
M+FYO=&4N9VYU+F)U:6QD+6ED`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS>6T`
M+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN
M`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y005))4T,N
M=6YW:6YD`"YE:%]F<F%M90`N;F]T92Y!0DDM=&%G`"YI;FET7V%R<F%Y`"YF
M:6YI7V%R<F%Y`"YD871A+G)E;"YR;P`N9'EN86UI8P`N9&%T80`N9V]T`"YB
M<W,`+F-O;6UE;G0`+FYO=&4`````````````````````````````````````
M````````````````````````"P````<````"``$!-````30````D````````
M```````$`````````!X````!`````@`!`5@```%8````#0``````````````
M`0`````````F;___]@````(``0%H```!:````/@````$``````````0````$
M````,`````L````"``$"8````F````8`````!0````$````$````$````#@`
M```#`````@`!"&````A@```$@0```````````````0````````!`;____P``
M``(``0SB```,X@```,`````$``````````(````"````36____X````"``$-
MI```#:0```!0````!0````$````$`````````%P````$`````@`!#?0```WT
M````/`````0`````````!`````P```!F````!````$(``0XP```.,````O0`
M```$````%@````0````,````<`````$````&``$1)```$20````<````````
M```````$`````````'8````!````!@`!$4```!%```!-@```````````````
M!`````````!\`````0````8``5[```!>P````"````````````````0`````
M````@@````$````"``%>X```7N```$$8```````````````$`````````(H`
M```!````0@`!G_@``)_X```"0``````````+````!`````0```"9`````0``
M``(``:(X``"B.`````0```````````````0`````````HP````<````"``&B
M/```HCP````@```````````````$`````````+$````.`````P`!L````+``
M````"```````````````!`````0```"]````#P````,``;`(``"P"`````0`
M``````````````0````$````R0````$````#``&P$```L!`````8````````
M```````(`````````-8````&`````P`!L"@``+`H````\`````4`````````
M!`````@```#?`````0````,``;$8``"Q&````!@```````````````0`````
M````:P````$````'``&Q,```L3````(T```````````````(`````````.4`
M```!`````P`!LV0``+-D````'```````````````!`````0```#J````"```
M``,``;.```"S@````#```````````````!``````````[P````$````P````
M````LX`````?```````````````!`````0```/@````'`````````````+.@
M````*```````````````!``````````!`````P````````````"SR````/X`
/``````````````$`````
